@@ -549,7 +549,7 @@ parse_error:
 SoupXmlrpcMessage*
 bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gnome_version,
 		        const char *username, const char *title, const char *text,
-		        GladeXML *xml, GError **err)
+		        GtkBuilder *ui, GError **err)
 {
 	SoupXmlrpcMessage *message;
 	char *user_agent;
@@ -558,7 +558,7 @@ bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gn
 	g_return_val_if_fail (gnome_version != NULL, NULL);
 	g_return_val_if_fail (username != NULL, NULL);
 	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (xml != NULL, NULL);
+	g_return_val_if_fail (ui != NULL, NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
 	/* FIXME: Hardcoded right now */
